aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-f5ethtrailer.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-f5ethtrailer.c')
-rw-r--r--epan/dissectors/packet-f5ethtrailer.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/epan/dissectors/packet-f5ethtrailer.c b/epan/dissectors/packet-f5ethtrailer.c
index 7924d8075c..708d055c3d 100644
--- a/epan/dissectors/packet-f5ethtrailer.c
+++ b/epan/dissectors/packet-f5ethtrailer.c
@@ -480,7 +480,7 @@ f5_udp_conv_valid(packet_info *pinfo)
* @return A filter string for the F5 IP conversation or NULL if no filter can be
* computed. The caller should free this string with g_free().
*
* @attention This function uses g_strdup_printf() rather than the wmem equivalent because the
* caller (menu_dissector_filter_cb()) uses g_free to free the filter string.
* (as of WS 1.12).
*/
@@ -496,7 +496,7 @@ f5_ip_conv_filter(packet_info *pinfo)
address_to_str_buf(&pinfo->src, src_addr, WS_INET6_ADDRSTRLEN);
address_to_str_buf(&pinfo->dst, dst_addr, WS_INET6_ADDRSTRLEN);
if (*src_addr != '\0' && *dst_addr != '\0') {
- buf = g_strdup_printf(
+ buf = ws_strdup_printf(
"(ip.addr eq %s and ip.addr eq %s) or"
" (f5ethtrailer.peeraddr eq %s and f5ethtrailer.peeraddr eq %s)",
src_addr, dst_addr, src_addr, dst_addr);
@@ -505,7 +505,7 @@ f5_ip_conv_filter(packet_info *pinfo)
address_to_str_buf(&pinfo->src, src_addr, WS_INET6_ADDRSTRLEN);
address_to_str_buf(&pinfo->dst, dst_addr, WS_INET6_ADDRSTRLEN);
if (*src_addr != '\0' && *dst_addr != '\0') {
- buf = g_strdup_printf(
+ buf = ws_strdup_printf(
"(ipv6.addr eq %s and ipv6.addr eq %s) or"
" (f5ethtrailer.peeraddr6 eq %s and f5ethtrailer.peeraddr6 eq %s)",
src_addr, dst_addr, src_addr, dst_addr);
@@ -535,7 +535,7 @@ f5_ip_conv_filter(packet_info *pinfo)
* be filtered properly. In the >=11.0.0 case, if you have TCP on one side and UDP on the other
* and it should "do the right thing".
*
* @attention This function uses g_strdup_printf() rather than the wmem equivalent because the
* caller (menu_dissector_filter_cb()) uses g_free to free the filter string.
* (as of WS 1.12).
*/
@@ -551,7 +551,7 @@ f5_tcp_conv_filter(packet_info *pinfo)
address_to_str_buf(&pinfo->src, src_addr, WS_INET6_ADDRSTRLEN);
address_to_str_buf(&pinfo->dst, dst_addr, WS_INET6_ADDRSTRLEN);
if (*src_addr != '\0' && *dst_addr != '\0') {
- buf = g_strdup_printf(
+ buf = ws_strdup_printf(
"(ip.addr eq %s and ip.addr eq %s and tcp.port eq %d and tcp.port eq %d) or"
" (f5ethtrailer.peeraddr eq %s and f5ethtrailer.peeraddr eq %s and"
" f5ethtrailer.peerport eq %d and f5ethtrailer.peerport eq %d and"
@@ -563,7 +563,7 @@ f5_tcp_conv_filter(packet_info *pinfo)
address_to_str_buf(&pinfo->src, src_addr, WS_INET6_ADDRSTRLEN);
address_to_str_buf(&pinfo->dst, dst_addr, WS_INET6_ADDRSTRLEN);
if (*src_addr != '\0' && *dst_addr != '\0') {
- buf = g_strdup_printf(
+ buf = ws_strdup_printf(
"(ipv6.addr eq %s and ipv6.addr eq %s and tcp.port eq %d and tcp.port eq %d) or"
" (f5ethtrailer.peeraddr6 eq %s and f5ethtrailer.peeraddr6 eq %s and"
" f5ethtrailer.peerport eq %d and f5ethtrailer.peerport eq %d and"
@@ -595,7 +595,7 @@ f5_tcp_conv_filter(packet_info *pinfo)
* be filtered properly. In the >=11.0.0 case, if you have TCP on one side and UDP on the other
* and it should "do the right thing".
*
* @attention This function uses g_strdup_printf() rather than the wmem equivalent because the
* caller (menu_dissector_filter_cb()) uses g_free to free the filter string.
* (as of WS 1.12).
*/
@@ -611,7 +611,7 @@ f5_udp_conv_filter(packet_info *pinfo)
address_to_str_buf(&pinfo->src, src_addr, WS_INET6_ADDRSTRLEN);
address_to_str_buf(&pinfo->dst, dst_addr, WS_INET6_ADDRSTRLEN);
if (*src_addr != '\0' && *dst_addr != '\0') {
- buf = g_strdup_printf(
+ buf = ws_strdup_printf(
"(ip.addr eq %s and ip.addr eq %s and udp.port eq %d and udp.port eq %d) or"
" (f5ethtrailer.peeraddr eq %s and f5ethtrailer.peeraddr eq %s and"
" f5ethtrailer.peerport eq %d and f5ethtrailer.peerport eq %d and"
@@ -623,7 +623,7 @@ f5_udp_conv_filter(packet_info *pinfo)
address_to_str_buf(&pinfo->src, src_addr, WS_INET6_ADDRSTRLEN);
address_to_str_buf(&pinfo->dst, dst_addr, WS_INET6_ADDRSTRLEN);
if (*src_addr != '\0' && *dst_addr != '\0') {
- buf = g_strdup_printf(
+ buf = ws_strdup_printf(
"(ipv6.addr eq %s and ipv6.addr eq %s and udp.port eq %d and udp.port eq %d) or"
" (f5ethtrailer.peeraddr6 eq %s and f5ethtrailer.peeraddr6 eq %s and"
" f5ethtrailer.peerport eq %d and f5ethtrailer.peerport eq %d and"
@@ -480,7 +480,7 @@ f5_udp_conv_valid(packet_info *pinfo)
* computed. The caller should free this string with g_free().
*
- * @attention This function uses g_strdup_printf() rather than the wmem equivalent because the
+ * @attention This function uses ws_strdup_printf() rather than the wmem equivalent because the
* caller (menu_dissector_filter_cb()) uses g_free to free the filter string.
* (as of WS 1.12).
@@ -535,7 +535,7 @@ f5_ip_conv_filter(packet_info *pinfo)
* and it should "do the right thing".
*
- * @attention This function uses g_strdup_printf() rather than the wmem equivalent because the
+ * @attention This function uses ws_strdup_printf() rather than the wmem equivalent because the
* caller (menu_dissector_filter_cb()) uses g_free to free the filter string.
* (as of WS 1.12).
@@ -595,7 +595,7 @@ f5_tcp_conv_filter(packet_info *pinfo)
* and it should "do the right thing".
*
- * @attention This function uses g_strdup_printf() rather than the wmem equivalent because the
+ * @attention This function uses ws_strdup_printf() rather than the wmem equivalent because the
* caller (menu_dissector_filter_cb()) uses g_free to free the filter string.
* (as of WS 1.12).